@@ -31,6 +31,11 @@ import eventlet.green.subprocess as subprocess
 
 from nflgame import OrderedDict
 
+try:
+    strtype = basestring
+except NameError:  # I have lofty hopes for Python 3.
+    strtype = str
+
 __pdoc__ = {}
 
 __broadcast_cache = {}  # game eid -> play id -> Play
@@ -275,6 +280,58 @@ def slice(footage_play_dir, full_footage_file, gobj, coach=True,
     _eprint('DONE slicing game %s %s' % (gobj.eid, _nice_game(gobj)))
 
 
+def slice_play(footage_play_dir, full_footage_file, gobj, play,
+               max_duration=0, cut_scoreboard=True, offset=0):
+    """
+    This is just like `nflvid.slice`, but it only slices the play
+    provided.  In typical cases, `nflvid.slice` should be used since it
+    makes sure not to duplicate work.
+
+    This function will not check if the play-by-play directory for
+    `gobj` has been created.
+
+    `max_duration` is used to cap the length of a play. This
+    drastically cuts down on the storage requirements of a game at the
+    cost of potentially missing longer plays. This is particularly
+    useful if you are slicing broadcast footage, where imposing a cap
+    at about 15 seconds can decrease storage requirements by more than
+    half without missing much.
+
+    When `cut_scoreboard` is `True`, the first 3.0 seconds of the play
+    will be clipped to remove the scoreboard view.
+
+    When `offset` is greater than `0`, it is subtracted from the start
+    time of `play` to get the actual start time used.
+    """
+    outdir = _play_path(footage_play_dir, gobj.eid)
+    st = play.start
+    outpath = path.join(outdir, '%s.mp4' % play.idstr())
+
+    st = st.add_seconds(-offset)
+    et = play.end
+    if et is None:  # Probably the last play of the game.
+        et = st.add_seconds(40)
+    if max_duration > 0 and (et.seconds() - st.seconds()) > max_duration:
+        et = st.add_seconds(max_duration)
+
+    if cut_scoreboard:
+        st = st.add_seconds(3.0)
+
+    dr = PlayTime(seconds=et.fractional() - st.fractional())
+
+    start_time = '%02d:%02d:%02d.%d' % (st.hh, st.mm, st.ss, st.milli)
+    duration = '%02d:%02d:%02d.%d' % (dr.hh, dr.mm, dr.ss, dr.milli)
+    cmd = ['ffmpeg',
+           '-ss', start_time,
+           '-t', duration,
+           '-i', full_footage_file,
+           '-acodec', 'copy',
+           '-vcodec', 'copy',
+           outpath,
+           ]
+    _run_command(cmd)
+
+
 def artificial_slice(footage_play_dir, gobj, gobj_play):
     """
     Creates a video file that contains a single static image with a
@@ -314,58 +371,6 @@ def artificial_slice(footage_play_dir, gobj, gobj_play):
         _run_command(cmd)
 
 
-def slice_play(footage_play_dir, full_footage_file, gobj, play,
-               max_duration=0, cut_scoreboard=True, offset=0):
-    """
-    This is just like `nflvid.slice`, but it only slices the play
-    provided.  In typical cases, `nflvid.slice` should be used since it
-    makes sure not to duplicate work.
-
-    This function will not check if the play-by-play directory for
-    `gobj` has been created.
-
-    `max_duration` is used to cap the length of a play. This
-    drastically cuts down on the storage requirements of a game at the
-    cost of potentially missing longer plays. This is particularly
-    useful if you are slicing broadcast footage, where imposing a cap
-    at about 15 seconds can decrease storage requirements by more than
-    half without missing much.
-
-    When `cut_scoreboard` is `True`, the first 3.0 seconds of the play
-    will be clipped to remove the scoreboard view.
-
-    When `offset` is greater than `0`, it is subtracted from the start
-    time of `play` to get the actual start time used.
-    """
-    outdir = _play_path(footage_play_dir, gobj.eid)
-    st = play.start
-    outpath = path.join(outdir, '%s.mp4' % play.idstr())
-
-    et = play.end
-    if et is None:  # Probably the last play of the game.
-        et = st.add_seconds(40)
-    if max_duration > 0 and (et.seconds() - st.seconds()) > max_duration:
-        et = st.add_seconds(max_duration)
-
-    if cut_scoreboard:
-        st = st.add_seconds(3.0)
-    st = st.add_seconds(-offset)
-
-    dr = PlayTime(seconds=et.fractional() - st.fractional())
-
-    start_time = '%02d:%02d:%02d.%d' % (st.hh, st.mm, st.ss, st.milli)
-    duration = '%02d:%02d:%02d.%d' % (dr.hh, dr.mm, dr.ss, dr.milli)
-    cmd = ['ffmpeg',
-           '-ss', start_time,
-           '-t', duration,
-           '-i', full_footage_file,
-           '-acodec', 'copy',
-           '-vcodec', 'copy',
-           outpath,
-           ]
-    _run_command(cmd)
-
-
 def download_broadcast(footage_dir, gobj, quality='1600', dry_run=False):
     """
     Starts an `ffmpeg` process to download the full broadcast of the
@@ -394,8 +399,10 @@ def download_broadcast(footage_dir, gobj, quality='1600', dry_run=False):
         _eprint('FAILED to download game %s' % _nice_game(gobj))
         return
 
-    cmd = ['ffmpeg',
-           '-i', url]
+    cmd = ['ffmpeg']
+    if not _is_avconv():
+        cmd += ['-timeout', '120']
+    cmd += ['-i', url]
     if dry_run:
         cmd += ['-t', '30']
     cmd += ['-absf', 'aac_adtstoasc',  # no idea. ffmpeg says I need it though.
@@ -449,6 +456,10 @@ def download_coach(footage_dir, gobj, dry_run=False):
                 % (gobj.eid, _nice_game(gobj)))
     elif not status:
         _eprint('FAILED to download game %s %s' % (gobj.eid, _nice_game(gobj)))
+        try:
+            os.remove(fp)
+        except OSError:
+            pass
     else:
         fp_size = 0
         try:
@@ -814,3 +825,11 @@ def _get_xml_data(eid=None, gamekey=None, fpath=None):
     except socket.timeout, e:
         _eprint(e)
     return None
+
+
+def _is_avconv():
+    """
+    Returns `True` if the `ffmpeg` binary is really `avconv`.
+    """
+    out = _run_command(['ffmpeg', '-version'])
+    return out and isinstance(out, strtype) and 'DEPRECATED' in out
